Skip to contentSkip to conversation

tags: skip ./ in filenames

PATCH Applied [email protected] 2 participants 2 messages Dec 1, 2008 – Dec 3, 2008 Kbuild

lore
Share & tools
lore
#0 lore raw

PATCH 4/8 tags: skip ./ in filenames

From: Alexey Dobriyan <[email protected]>

This drives size of tags file from 68.9 MB down to 67.7 MB.

---

 Makefile |    2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
Makefile renamed from Makefile~tags-skip-in-filenames +1 -1
diff -puN Makefile~tags-skip-in-filenames Makefile
@@ -1456,7 +1456,7 @@ define find-sources
 	       -name $1 -print; \
 	  find $(__srctree) $(RCS_FIND_IGNORE) \
 	       \( -name include -o -name arch -o -name '.tmp_*' \) -prune -o \
-	       -name $1 -print; \
+	       -name $1 -print | sed -e 's#^./##'; \
 	  )
 endef
 

_